@@ -30,15 +30,15 @@ from acconeer.exptool.app.new import (
     GeneralMessage,
     HandledException,
     Message,
-    Plugin,
     PluginFamily,
     PluginGeneration,
+    PluginSpecBase,
     PluginState,
     PluginStateMessage,
     get_temp_h5_path,
     is_task,
 )
-from acconeer.exptool.app.new.ui.plugin import (
+from acconeer.exptool.app.new.ui.plugin_components import (
     AttrsConfigEditor,
     GridGroupBox,
     PidgetFactoryMapping,
@@ -519,17 +519,17 @@ class ViewPlugin(DetectorViewPluginBase):
 
     def __init__(self, app_model: AppModel, view_widget: QWidget) -> None:
         super().__init__(app_model=app_model, view_widget=view_widget)
+        self.app_model = app_model
 
-        self.view_layout = QVBoxLayout(self.view_widget)
-        self.view_layout.setContentsMargins(0, 0, 0, 0)
-        self.view_widget.setLayout(self.view_layout)
-
-        # TODO: Fix parents
+        sticky_layout = QVBoxLayout()
+        sticky_layout.setContentsMargins(0, 0, 0, 0)
+        scrolly_layout = QVBoxLayout()
+        scrolly_layout.setContentsMargins(0, 0, 0, 0)
 
         self.start_button = QPushButton(
             qta.icon("fa5s.play-circle", color=BUTTON_ICON_COLOR),
             "Start measurement",
-            self.view_widget,
+            self.sticky_widget,
         )
         self.start_button.setShortcut("space")
         self.start_button.clicked.connect(self._send_start_request)
@@ -537,7 +537,7 @@ class ViewPlugin(DetectorViewPluginBase):
         self.stop_button = QPushButton(
             qta.icon("fa5s.stop-circle", color=BUTTON_ICON_COLOR),
             "Stop",
-            self.view_widget,
+            self.sticky_widget,
         )
         self.stop_button.setShortcut("space")
         self.stop_button.clicked.connect(self._send_stop_request)
@@ -545,55 +545,57 @@ class ViewPlugin(DetectorViewPluginBase):
         self.record_threshold_button = QPushButton(
             qta.icon("fa.video-camera", color=BUTTON_ICON_COLOR),
             "Record threshold",
-            self.view_widget,
+            self.sticky_widget,
         )
         self.record_threshold_button.clicked.connect(self._on_record_threshold)
 
         self.close_range_calibration_button = QPushButton(
             qta.icon("mdi.adjust", color=BUTTON_ICON_COLOR),
             "Calibrate close range",
-            self.view_widget,
+            self.sticky_widget,
         )
         self.close_range_calibration_button.clicked.connect(self._on_close_range_calibration)
 
         self.defaults_button = QPushButton(
             qta.icon("mdi6.restore", color=BUTTON_ICON_COLOR),
             "Reset settings and calibrations",
-            self.view_widget,
+            self.sticky_widget,
         )
         self.defaults_button.clicked.connect(self._send_defaults_request)
 
-        self.message_box = QLabel(self.view_widget)
+        self.message_box = QLabel(self.sticky_widget)
         self.message_box.setWordWrap(True)
 
-        button_group = GridGroupBox("Controls", parent=self.view_widget)
+        button_group = GridGroupBox("Controls", parent=self.sticky_widget)
         button_group.layout().addWidget(self.start_button, 0, 0)
         button_group.layout().addWidget(self.stop_button, 0, 1)
         button_group.layout().addWidget(self.close_range_calibration_button, 1, 0)
         button_group.layout().addWidget(self.record_threshold_button, 1, 1)
         button_group.layout().addWidget(self.defaults_button, 2, 0, 1, -1)
         button_group.layout().addWidget(self.message_box, 3, 0, 1, -1)
-        self.view_layout.addWidget(button_group)
+
+        sticky_layout.addWidget(button_group)
 
         sensor_selection_group = utils.VerticalGroupBox(
-            "Sensor selection", parent=self.view_widget
+            "Sensor selection", parent=self.scrolly_widget
         )
         self.sensor_id_pidget = pidgets.SensorIdParameterWidgetFactory(items=[]).create(
             parent=sensor_selection_group
         )
         self.sensor_id_pidget.sig_parameter_changed.connect(self._on_sensor_id_update)
         sensor_selection_group.layout().addWidget(self.sensor_id_pidget)
-        self.view_layout.addWidget(sensor_selection_group)
+        scrolly_layout.addWidget(sensor_selection_group)
 
         self.config_editor = AttrsConfigEditor[DetectorConfig](
             title="Detector parameters",
             factory_mapping=self._get_pidget_mapping(),
-            parent=self.view_widget,
+            parent=self.scrolly_widget,
         )
         self.config_editor.sig_update.connect(self._on_config_update)
-        self.view_layout.addWidget(self.config_editor)
+        scrolly_layout.addWidget(self.config_editor)
 
-        self.view_layout.addStretch(1)
+        self.sticky_widget.setLayout(sticky_layout)
+        self.scrolly_widget.setLayout(scrolly_layout)
 
     @classmethod
     def _get_pidget_mapping(cls) -> PidgetFactoryMapping:
@@ -697,7 +699,9 @@ class ViewPlugin(DetectorViewPluginBase):
         self.sensor_id_pidget.set_parameter(state.sensor_id)
         self.sensor_id_pidget.setEnabled(app_model.plugin_state.is_steady)
 
-        detector_status = Detector.get_detector_status(state.config, state.context)
+        detector_status = Detector.get_detector_status(
+            state.config, state.context, state.sensor_id
+        )
 
         self.message_box.setText(self.TEXT_MSG_MAP[detector_status.detector_state])
 
@@ -752,18 +756,26 @@ class ViewPlugin(DetectorViewPluginBase):
     def _send_defaults_request(self) -> None:
         self.app_model.put_backend_plugin_task("restore_defaults")
 
-    # TODO: move to detector base (?)
-    def teardown(self) -> None:
-        self.view_layout.deleteLater()
+
+class PluginSpec(PluginSpecBase):
+    def create_backend_plugin(
+        self, callback: Callable[[Message], None], key: str
+    ) -> BackendPlugin:
+        return BackendPlugin(callback, key)
+
+    def create_view_plugin(self, app_model: AppModel, view_widget: QWidget) -> ViewPlugin:
+        return ViewPlugin(app_model=app_model, view_widget=view_widget)
+
+    def create_plot_plugin(
+        self, app_model: AppModel, plot_layout: pg.GraphicsLayout
+    ) -> PlotPlugin:
+        return PlotPlugin(app_model=app_model, plot_layout=plot_layout)
 
 
-DISTANCE_DETECTOR_PLUGIN = Plugin(
+DISTANCE_DETECTOR_PLUGIN = PluginSpec(
     generation=PluginGeneration.A121,
     key="distance_detector",
     title="Distance detector",
     description="Easily measure distance to objects.",
     family=PluginFamily.DETECTOR,
-    backend_plugin=BackendPlugin,
-    plot_plugin=PlotPlugin,
-    view_plugin=ViewPlugin,
 )
